.. _geometry_converter:

========================
Camera image conversions
========================

converts 1D image containers to 2D
transforms hexagonal images into rectangular grid

.. automodapi:: ctapipe.image.geometry_converter
